mechcite package
================

Submodules
----------

mechcite.bibliography module
----------------------------

.. automodule:: mechcite.bibliography
    :members:
    :undoc-members:
    :show-inheritance:

mechcite.citation module
------------------------

.. automodule:: mechcite.citation
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: mechcite
    :members:
    :undoc-members:
    :show-inheritance:
